.group-toolbar[data-v-46ef16a6]{align-items:center;border-bottom:1px solid #4e4e52;display:flex;height:46px;padding:0 10px}.group-toolbar .q-btn[data-v-46ef16a6]{margin-right:10px}.group-toolbar .q-btn .q-spinner[data-v-46ef16a6]{font-size:8px}.dialog-class .dialog-card[data-v-46ef16a6]{background:#1e1e1e;max-width:400px;padding:10px;width:400px}.dialog-class .dialog-card .header-text[data-v-46ef16a6]{font-size:16px}.page-black[data-v-0dfda669]{background:#35363a}.setting-toolbar[data-v-0dfda669]{align-items:center;color:#aaa;display:flex;height:54px;justify-content:space-between;padding:0 10px}.info-table[data-v-0dfda669]{align-items:center;border-bottom:1px solid #4e4e52;display:flex;line-height:42px;margin:0 10px}.info-table .left[data-v-0dfda669]{align-items:center;color:#fff;display:flex;flex:40%;flex-direction:row}.info-table .left .info-link[data-v-0dfda669]{align-items:center;cursor:pointer;display:flex;flex-direction:row}.info-table .left .info-link .title[data-v-0dfda669]{margin-right:10px}.info-table .left .info-link .domian[data-v-0dfda669]{color:#aaa}.info-table .left .info-link .icon[data-v-0dfda669]{align-items:center;background:#1976d2;border-radius:50%;color:#fff;display:flex;height:24px;justify-content:center;margin-right:10px;width:24px}.info-table .left .info-link .icon-green[data-v-0dfda669]{background:#f44336}.info-table .center[data-v-0dfda669]{align-items:center;color:#aaa;display:flex;flex:20%}.info-table .center .info[data-v-0dfda669]{flex-shrink:0;margin-left:10px;min-width:100px;text-align:left}.info-table .right[data-v-0dfda669]{display:flex;flex:1;flex-direction:row;height:100%;justify-content:flex-end}.dialog-class .dialog-card[data-v-0dfda669]{background:#1e1e1e;max-width:500px;padding:10px;width:500px}.dialog-class .dialog-card .header-text[data-v-0dfda669]{font-size:16px}.detail-info div[data-v-0dfda669]{line-height:30px}.detail-info .margin-l-20[data-v-0dfda669]{margin-left:20px}