"use strict";(globalThis["webpackChunkquasar_project"]=globalThis["webpackChunkquasar_project"]||[]).push([[862],{1862:(e,t,o)=>{o.r(t),o.d(t,{default:()=>b});var n=o(9835);const l={class:"fullscreen bg-blue text-white text-center q-pa-md flex flex-center"},s=(0,n._)("div",{style:{"font-size":"30vh"}}," 404 ",-1),a=(0,n._)("div",{class:"text-h2",style:{opacity:".4"}}," Oops. Nothing here... ",-1);function c(e,t,o,c,r,u){const i=(0,n.up)("q-btn");return(0,n.wg)(),(0,n.iD)("div",l,[(0,n._)("div",null,[s,a,(0,n.Wm)(i,{class:"q-mt-xl",color:"white","text-color":"blue",unelevated:"",to:"/",label:"Go Home","no-caps":""})])])}const r=(0,n.aZ)({name:"ErrorNotFound"});var u=o(1639),i=o(4455),h=o(9984),p=o.n(h);const d=(0,u.Z)(r,[["render",c]]),b=d;p()(r,"components",{QBtn:i.Z})}}]);