"use strict";(globalThis["webpackChunkquasar_project"]=globalThis["webpackChunkquasar_project"]||[]).push([[200],{1200:(t,e,a)=>{a.r(e),a.d(e,{default:()=>W});var n=a(9835);const o=t=>((0,n.dD)("data-v-c1ba23ce"),t=t(),(0,n.Cn)(),t),r=o((()=>(0,n._)("div",{class:"col text-center text-weight-bold"}," DomianAdmin ",-1)));function i(t,e,a,o,i,c){const l=(0,n.up)("q-bar"),u=(0,n.up)("q-header"),s=(0,n.up)("router-view"),p=(0,n.up)("q-page-container"),d=(0,n.up)("q-layout");return(0,n.wg)(),(0,n.j4)(d,{view:"lHh Lpr lFf"},{default:(0,n.w5)((()=>[(0,n.Wm)(u,{elevated:"",class:"q-electron-drag"},{default:(0,n.w5)((()=>[(0,n.Wm)(l,{dark:"",class:"pd-bg-black text-white"},{default:(0,n.w5)((()=>[r])),_:1})])),_:1}),(0,n.Wm)(p,null,{default:(0,n.w5)((()=>[(0,n.Wm)(s)])),_:1})])),_:1})}var c=a(499),l=a(6970);function u(t,e,a,o,r,i){const c=(0,n.up)("q-icon"),u=(0,n.up)("q-item-section"),s=(0,n.up)("q-item-label"),p=(0,n.up)("q-item");return(0,n.wg)(),(0,n.j4)(p,{clickable:"",tag:"a",target:"_blank",href:t.link},{default:(0,n.w5)((()=>[t.icon?((0,n.wg)(),(0,n.j4)(u,{key:0,avatar:""},{default:(0,n.w5)((()=>[(0,n.Wm)(c,{name:t.icon},null,8,["name"])])),_:1})):(0,n.kq)("",!0),(0,n.Wm)(u,null,{default:(0,n.w5)((()=>[(0,n.Wm)(s,null,{default:(0,n.w5)((()=>[(0,n.Uk)((0,l.zw)(t.title),1)])),_:1}),(0,n.Wm)(s,{caption:""},{default:(0,n.w5)((()=>[(0,n.Uk)((0,l.zw)(t.caption),1)])),_:1})])),_:1})])),_:1},8,["href"])}const s=(0,n.aZ)({name:"EssentialLink",props:{title:{type:String,required:!0},caption:{type:String,default:""},link:{type:String,default:"#"},icon:{type:String,default:""}}});var p=a(1639),d=a(490),m=a(1233),k=a(2857),w=a(3115),f=a(9984),h=a.n(f);const q=(0,p.Z)(s,[["render",u]]),v=q;h()(s,"components",{QItem:d.Z,QItemSection:m.Z,QIcon:k.Z,QItemLabel:w.Z});const b=[{title:"Docs",caption:"quasar.dev",icon:"school",link:"https://quasar.dev"},{title:"Github",caption:"github.com/quasarframework",icon:"code",link:"https://github.com/quasarframework"},{title:"Discord Chat Channel",caption:"chat.quasar.dev",icon:"chat",link:"https://chat.quasar.dev"},{title:"Forum",caption:"forum.quasar.dev",icon:"record_voice_over",link:"https://forum.quasar.dev"},{title:"Twitter",caption:"@quasarframework",icon:"rss_feed",link:"https://twitter.quasar.dev"},{title:"Facebook",caption:"@QuasarFramework",icon:"public",link:"https://facebook.quasar.dev"},{title:"Quasar Awesome",caption:"Community Quasar projects",icon:"favorite",link:"https://awesome.quasar.dev"}],g=(0,n.aZ)({name:"MainLayout",components:{EssentialLink:v},setup(){const t=(0,c.iH)(!1);return{essentialLinks:b,leftDrawerOpen:t,toggleLeftDrawer(){t.value=!t.value}}}});var _=a(7605),Z=a(6602),Q=a(4526),y=a(2133);const L=(0,p.Z)(g,[["render",i],["__scopeId","data-v-c1ba23ce"]]),W=L;h()(g,"components",{QLayout:_.Z,QHeader:Z.Z,QBar:Q.Z,QPageContainer:y.Z})}}]);